@@ -1272,6 +1272,8 @@ evdev_read_model_flags(struct evdev_device *device)
 		MODEL(LOGITECH_MARBLE_MOUSE),
 		MODEL(TABLET_NO_PROXIMITY_OUT),
 		MODEL(MS_NANO_TRANSCEIVER),
+		MODEL(TABLET_MODE_NO_SUSPEND),
+		MODEL(LENOVO_CARBON_X1_6TH),
 #undef MODEL
 		{ "ID_INPUT_TRACKBALL", EVDEV_MODEL_TRACKBALL },
 		{ NULL, EVDEV_MODEL_DEFAULT },
@@ -1868,6 +1870,13 @@ evdev_pre_configure_model_quirks(struct evdev_device *device)
 	/* Logitech Marble Mouse claims to have a middle button */
 	if (device->model_flags & EVDEV_MODEL_LOGITECH_MARBLE_MOUSE)
 		libevdev_disable_event_code(device->evdev, EV_KEY, BTN_MIDDLE);
+
+	/* Lenovo Carbon X1 6th gen sends bogus ABS_MT_TOOL_TYPE events for
+	 * MT_TOOL_PALM */
+	if (device->model_flags & EVDEV_MODEL_LENOVO_CARBON_X1_6TH)
+		libevdev_disable_event_code(device->evdev,
+					    EV_ABS,
+					    ABS_MT_TOOL_TYPE);
 }
 
 static void
